#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_EXTRACT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_EXTRACT_HPP_INCLUDED

#include <boost/simd/memory/include/functions/extract.hpp>

#endif
